==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/fr/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(visible également pour les non-membres de cet espace)',
  '<strong>Delete</strong> content?' => '<strong>Supprimer</strong> le contenu ?',
  '<strong>Move</strong> content' => '<strong>Déplacer</strong> le contenu',
  '<strong>Permalink</strong> to this post' => '<strong>Raccourci</strong> vers cette publication',
  '<strong>Scheduling</strong> Options' => 'Options de <strong>planification</strong>',
  'Activate scheduling' => 'Activer la planification',
  'Activated' => 'Activé',
  'Add a member to notify' => 'Ajouter un membre à notifier',
  'Add tag...' => 'Ajouter un mot-clé...',
  'Archived' => 'Archivé',
  'Attach Files' => 'Joindre des fichiers',
  'Back to stream' => 'Retour au fil d\'actualités',
  'Cancel' => 'Annuler',
  'Cancel Edit' => 'Annuler la modification',
  'Cannot notify the author.' => 'Impossible de notifier l’auteur.',
  'Change to "Private"' => 'Rendre privé',
  'Change to "Public"' => 'Rendre public',
  'Comments are locked' => 'Les commentaires sont désactivés',
  'Comments are unlocked' => 'Les commentaires sont activés',
  'Configure' => 'Configurer',
  'Confirm' => 'Confirmer',
  'Content' => 'Contenu',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Mot-clé de contenu associé à un contentcontainer_id invalide.',
  'Content has been moved to {spacename}' => 'Le contenu a été déplacé dans {spacename}',
  'Could not find requested content!' => 'Impossible de trouver le contenu demandé !',
  'Create as draft' => 'Créer comme brouillon',
  'Created at:' => 'Créé le :',
  'Created by me' => 'Créé par moi',
  'Creation time' => 'Date de création',
  'Delete' => 'Supprimer',
  'Deleted' => 'Supprimé',
  'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Voulez-vous supprimer ce contenu ainsi que tous ses commentaires et pièces jointes ?<br><br>Note : si une entrée du fil a été créée avec un module, le contenu original lié à cette entrée sera également supprimé.',
  'Draft' => 'Brouillon',
  'Edit' => 'Modifier',
  'Enable' => 'Activer',
  'Filter' => 'Filtrer',
  'Hidden' => 'Masqué',
  'I\'m involved' => 'Là où je participe',
  'Invalid content id given!' => 'ID de contenu incorrect.',
  'Invalid request method!' => 'Méthode de demande non valide.',
  'Invalid space selection.' => 'Sélection d\'espace invalide',
  'Last update' => 'Dernière mise à jour',
  'Last updated {time}' => 'Dernière mise à jour: {time}',
  'Load more' => 'Afficher plus',
  'Lock comments' => 'Désactiver les commentaires',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'La limite des publications mises en avant est atteinte.<br>Vous ne pouvez mettre en avant que {count} publications maximum.',
  'Move content' => 'Déplacer le contenu',
  'Move to archive' => 'Archiver',
  'New Updates Available!' => 'Nouvelles mises à jour disponibles !',
  'No matches with your selected filters!' => 'Aucun résultat avec les filtres sélectionnés.',
  'No tags found for the given query' => 'Aucun mot-clé trouvé pour cette requête',
  'None' => 'Aucun',
  'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Remarque : pour des raisons techniques, il peut y avoir un délai de quelques minutes.',
  'Nothing here yet!' => 'Rien à afficher actuellement.',
  'Notify members' => 'Avertir des utilisateurs',
  'Permalink' => 'Permalien',
  'Pin to top' => 'Épingler en haut de page',
  'Pinned' => 'Épinglé',
  'Private' => 'Privé',
  'Public' => 'Public',
  'Publish draft' => 'Publier le brouillon',
  'Save as draft' => 'Enregistrer comme brouillon',
  'Save scheduling' => 'Sauvegarder la planification',
  'Schedule publication' => 'Planifier la publication',
  'Scheduled for {dateTime}' => 'Planifié pour le {dateTime}',
  'Select type...' => 'Sélectionner le type...',
  'Specify who can see this content.' => 'Spécifier qui peut voir ce contenu.',
  'Submit' => 'Publier',
  'Tag' => 'Mot-clé',
  'Target Space' => 'Espace Cible',
  'The author of this content is not allowed to create private content within the selected space.' => 'L\'auteur de ce contenu n\'est pas autorisé à créé du contenu privé dans l\'espace sélectionné',
  'The author of this content is not allowed to create public content within the selected space.' => 'L\'auteur de ce contenu n\'est pas autorisé à créé du contenu privé dans l\'espace sélectionné',
  'The author of this content is not allowed to create this type of content within this space.' => 'L\'auteur de cette publication n\'est pas autorisé à publier ce type de contenu dans cet espace.',
  'The content can\'t be moved to its current space.' => 'Le contenu ne peut êtres transféré dans l\'espace courant.',
  'The content cannot be published!' => 'Le contenu ne peut pas être publié !',
  'The content has been archived.' => 'Le contenu a été archivé.',
  'The content has been deleted.' => 'Le contenu a été supprimé.',
  'The content has been successfully published.' => 'Le contenu a été publié avec succès.',
  'The content has been unarchived.' => 'Le contenu a été désarchivé.',
  'The given name is already in use.' => 'Ce nom est déjà utilisé.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Le module {moduleName} n\'est pas disponible dans l\'espace sélectionné.',
  'This action is disabled!' => 'Cette action est désactivée.',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Ce type de contenu ne peut êtres déplacé car il manque le paramètre module-id',
  'This content type can\'t be moved.' => 'Ce contenu ne peut être déplacé.',
  'This space is archived.' => 'Cet espace est archivé',
  'This space is not visible!' => 'Cet espace n\'est pas visible.',
  'Topics' => 'Sujets',
  'Turn off notifications' => 'Désactiver les notifications',
  'Turn on notifications' => 'Activer les notifications',
  'Unarchive' => 'Désarchiver',
  'Unlock comments' => 'Activer les commentaires',
  'Unpin' => 'Détacher',
  'Updated' => 'Mis à jour',
  'Visible also to unregistered users' => 'Visible par tout le monde (y compris par les personnes non enregistrées)',
  'Visible only to you' => 'Visible par moi uniquement',
  'Visible to all Space members' => 'Visible par tous les membres de l\'espace',
  'Visible to all signed in users' => 'Visible par toutes les personnes connectées',
  'Visible to friends of {displayName}' => 'Visible par les amis de {displayName}',
  'Visible to you and {displayName}' => 'Visible par moi et {displayName}',
  'Visible to your friends' => 'Visible par mes amis',
  'With attachments' => 'Avec fichiers joints',
  'You cannot block the space owner!' => 'Vous ne pouvez pas bloquer la ou le propriétaire de l’espace.',
  'You cannot block the user of the same container!' => 'Vous ne pouvez pas bloquer l’utilisateur ou l’utilisatrice du même conteneur.',
  'You cannot block yourself!' => 'Vous ne pouvez pas vous bloquer vous-même.',
  'You do not have the permission to move this content to the given space.' => 'Vous n\'êtes pas autorisé à déplacer cette publication vers l\'espace sélectionné.',
  'You do not have the permission to move this content.' => 'Vous n\'êtes pas autorisé à déplacer cette publication.',
  'Your last edit state has been saved!' => 'Votre dernier état d\'édition a été sauvegardé.',
  'in' => 'dans',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/content/messages/fr/base.php <==
<?php
return array (
  '(Also visible to non-members of this space)' => '(visible également pour les non-membres de cet espace)',
  '<strong>Delete</strong> content?' => '<strong>Supprimer</strong> le contenu ?',
  '<strong>Move</strong> content' => '<strong>Déplacer</strong> le contenu',
  '<strong>Permalink</strong> to this post' => '<strong>Raccourci</strong> vers cette publication',
  '<strong>Scheduling</strong> Options' => 'Options de <strong>planification</strong>',
  'Activate scheduling' => 'Activer la planification',
  'Add a member to notify' => 'Ajouter un membre à notifier',
  'Add tag...' => 'Ajouter un mot-clé...',
  'Advanced Content Search' => 'Recherche avancée de contenu',
  'Archived' => 'Archivé',
  'Attach Files' => 'Joindre des fichiers',
  'Back to stream' => 'Retour au fil d\'actualités',
  'Cancel' => 'Annuler',
  'Cancel Edit' => 'Annuler la modification',
  'Cannot notify the author.' => 'Impossible de notifier l’auteur.',
  'Change to "Private"' => 'Rendre privé',
  'Change to "Public"' => 'Rendre public',
  'Comments are locked' => 'Les commentaires sont désactivés',
  'Comments are unlocked' => 'Les commentaires sont activés',
  'Configure' => 'Configurer',
  'Confirm' => 'Confirmer',
  'Content' => 'Contenu',
  'Content Tag with invalid contentcontainer_id assigned.' => 'Mot-clé de contenu associé à un contentcontainer_id invalide.',
  'Content has been moved to {spacename}' => 'Le contenu a été déplacé dans {spacename}',
  'Could not find requested content!' => 'Impossible de trouver le contenu demandé !',
  'Create as draft' => 'Créer comme brouillon',
  'Created at:' => 'Créé le :',
  'Created by me' => 'Créé par moi',
  'Creation time' => 'Date de création',
  'Delete' => 'Supprimer',
  'Deleted' => 'Supprimé',
  'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => 'Voulez-vous supprimer ce contenu ainsi que tous ses commentaires et pièces jointes ?<br><br>Note : si une entrée du fil a été créée avec un module, le contenu original lié à cette entrée sera également supprimé.',
  'Draft' => 'Brouillon',
  'Edit' => 'Modifier',
  'Enable' => 'Activer',
  'Enabled' => 'Activé',
  'Filter' => 'Filtrer',
  'Hidden' => 'Masqué',
  'I\'m involved' => 'Là où je participe',
  'Invalid content id given!' => 'ID de contenu incorrect.',
  'Invalid request method!' => 'Méthode de demande non valide.',
  'Invalid space selection.' => 'Sélection d\'espace invalide',
  'Last update' => 'Dernière mise à jour',
  'Last updated {time}' => 'Dernière mise à jour: {time}',
  'Load more' => 'Afficher plus',
  'Lock comments' => 'Désactiver les commentaires',
  'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => 'La limite des publications mises en avant est atteinte.<br>Vous ne pouvez mettre en avant que {count} publications maximum.',
  'Move content' => 'Déplacer le contenu',
  'Move to archive' => 'Archiver',
  'New Updates Available!' => 'Nouvelles mises à jour disponibles !',
  'No matches with your selected filters!' => 'Aucun résultat avec les filtres sélectionnés.',
  'No tags found for the given query' => 'Aucun mot-clé trouvé pour cette requête',
  'None' => 'Aucun',
  'Note: Due to technical reasons there may be a delay of a few minutes.' => 'Remarque : pour des raisons techniques, il peut y avoir un délai de quelques minutes.',
  'Nothing here yet!' => 'Rien à afficher actuellement.',
  'Notify members' => 'Avertir des utilisateurs',
  'Permalink' => 'Permalien',
  'Pin to top' => 'Épingler en haut de page',
  'Pinned' => 'Épinglé',
  'Private' => 'Privé',
  'Public' => 'Public',
  'Publish draft' => 'Publier le brouillon',
  'Save as draft' => 'Enregistrer comme brouillon',
  'Save scheduling' => 'Sauvegarder la planification',
  'Schedule publication' => 'Planifier la publication',
  'Scheduled for {dateTime}' => 'Planifié pour le {dateTime}',
  'Select type...' => 'Sélectionner le type...',
  'Specify who can see this content.' => 'Spécifier qui peut voir ce contenu.',
  'Submit' => 'Publier',
  'Tag' => 'Mot-clé',
  'Target Space' => 'Espace Cible',
  'The author of this content is not allowed to create private content within the selected space.' => 'L\'auteur de ce contenu n\'est pas autorisé à créé du contenu privé dans l\'espace sélectionné',
  'The author of this content is not allowed to create public content within the selected space.' => 'L\'auteur de ce contenu n\'est pas autorisé à créé du contenu privé dans l\'espace sélectionné',
  'The author of this content is not allowed to create this type of content within this space.' => 'L\'auteur de cette publication n\'est pas autorisé à publier ce type de contenu dans cet espace.',
  'The content can\'t be moved to its current space.' => 'Le contenu ne peut êtres transféré dans l\'espace courant.',
  'The content cannot be published!' => 'Le contenu ne peut pas être publié !',
  'The content has been archived.' => 'Le contenu a été archivé.',
  'The content has been deleted.' => 'Le contenu a été supprimé.',
  'The content has been successfully published.' => 'Le contenu a été publié avec succès.',
  'The content has been unarchived.' => 'Le contenu a été désarchivé.',
  'The given name is already in use.' => 'Ce nom est déjà utilisé.',
  'The module {moduleName} is not enabled on the selected target space.' => 'Le module {moduleName} n\'est pas disponible dans l\'espace sélectionné.',
  'This action is disabled!' => 'Cette action est désactivée.',
  'This content type can\'t be moved due to a missing module-id setting.' => 'Ce type de contenu ne peut êtres déplacé car il manque le paramètre module-id',
  'This content type can\'t be moved.' => 'Ce contenu ne peut être déplacé.',
  'This space is archived.' => 'Cet espace est archivé',
  'This space is not visible!' => 'Cet espace n\'est pas visible.',
  'Topics' => 'Sujets',
  'Turn off notifications' => 'Désactiver les notifications',
  'Turn on notifications' => 'Activer les notifications',
  'Unarchive' => 'Désarchiver',
  'Unlock comments' => 'Activer les commentaires',
  'Unpin' => 'Détacher',
  'Updated' => 'Mis à jour',
  'Visible also to unregistered users' => 'Visible par tout le monde (y compris par les personnes non enregistrées)',
  'Visible only to you' => 'Visible par moi uniquement',
  'Visible to all Space members' => 'Visible par tous les membres de l\'espace',
  'Visible to all signed in users' => 'Visible par toutes les personnes connectées',
  'Visible to friends of {displayName}' => 'Visible par les amis de {displayName}',
  'Visible to you and {displayName}' => 'Visible par moi et {displayName}',
  'Visible to your friends' => 'Visible par mes amis',
  'With attachments' => 'Avec fichiers joints',
  'You cannot block the space owner!' => 'Vous ne pouvez pas bloquer la ou le propriétaire de l’espace.',
  'You cannot block the user of the same container!' => 'Vous ne pouvez pas bloquer l’utilisateur ou l’utilisatrice du même conteneur.',
  'You cannot block yourself!' => 'Vous ne pouvez pas vous bloquer vous-même.',
  'You do not have the permission to move this content to the given space.' => 'Vous n\'êtes pas autorisé à déplacer cette publication vers l\'espace sélectionné.',
  'You do not have the permission to move this content.' => 'Vous n\'êtes pas autorisé à déplacer cette publication.',
  'Your last edit state has been saved!' => 'Votre dernier état d\'édition a été sauvegardé.',
  'in' => 'dans',
);
